==> eam-wshub-proxyclient-11.7-3-sources.jar: net/datastream/schemas/mp_fields/EXTMENU_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlSeeAlso;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for EXTMENU_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="EXTMENU_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EXTMENUCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EXTMENUPARENT"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EXTMENUTYPE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SEQUENCENUMBER"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}HIDEMENU" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MOBILE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MOBILEICON" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DUX" minOccurs="0"/>
 *         &lt;element name="UPDATECOUNT" type="{http://www.w3.org/2001/XMLSchema}long"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "EXTMENU_Type", propOrder = {
    "extmenucode",
    "extmenuparent",
    "extmenutype",
    "sequencenumber",
    "hidemenu",
    "mobile",
    "mobileicon",
    "dux",
    "updatecount"
})
@XmlSeeAlso({
    MENU_Type.class,
    FUNCTION_Type.class,
    FOLDER_Type.class
})
public class EXTMENU_Type {

    @XmlElement(name = "EXTMENUCODE", required = true)
    protected String extmenucode;
    @XmlElement(name = "EXTMENUPARENT", required = true)
    protected String extmenuparent;
    @XmlElement(name = "EXTMENUTYPE", required = true)
    protected String extmenutype;
    @XmlElement(name = "SEQUENCENUMBER")
    protected long sequencenumber;
    @XmlElement(name = "HIDEMENU")
    protected String hidemenu;
    @XmlElement(name = "MOBILE")
    protected String mobile;
    @XmlElement(name = "MOBILEICON")
    protected String mobileicon;
    @XmlElement(name = "DUX")
    protected String dux;
    @XmlElement(name = "UPDATECOUNT")
    protected long updatecount;

    /**
     * Gets the value of the extmenucode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEXTMENUCODE() {
        return extmenucode;
    }

    /**
     * Sets the value of the extmenucode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEXTMENUCODE(String value) {
        this.extmenucode = value;
    }

    /**
     * Gets the value of the extmenuparent property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEXTMENUPARENT() {
        return extmenuparent;
    }

    /**
     * Sets the value of the extmenuparent property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEXTMENUPARENT(String value) {
        this.extmenuparent = value;
    }

    /**
     * Gets the value of the extmenutype property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEXTMENUTYPE() {
        return extmenutype;
    }

    /**
     * Sets the value of the extmenutype property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEXTMENUTYPE(String value) {
        this.extmenutype = value;
    }

    /**
     * Gets the value of the sequencenumber property.
     * 
     */
    public long getSEQUENCENUMBER() {
        return sequencenumber;
    }

    /**
     * Sets the value of the sequencenumber property.
     * 
     */
    public void setSEQUENCENUMBER(long value) {
        this.sequencenumber = value;
    }

    /**
     * Gets the value of the hidemenu property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getHIDEMENU() {
        return hidemenu;
    }

    /**
     * Sets the value of the hidemenu property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setHIDEMENU(String value) {
        this.hidemenu = value;
    }

    /**
     * Gets the value of the mobile property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMOBILE() {
        return mobile;
    }

    /**
     * Sets the value of the mobile property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMOBILE(String value) {
        this.mobile = value;
    }

    /**
     * Gets the value of the mobileicon property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMOBILEICON() {
        return mobileicon;
    }

    /**
     * Sets the value of the mobileicon property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMOBILEICON(String value) {
        this.mobileicon = value;
    }

    /**
     * Gets the value of the dux property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDUX() {
        return dux;
    }

    /**
     * Sets the value of the dux property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDUX(String value) {
        this.dux = value;
    }

    /**
     * Gets the value of the updatecount property.
     * 
     */
    public long getUPDATECOUNT() {
        return updatecount;
    }

    /**
     * Sets the value of the updatecount property.
     * 
     */
    public void setUPDATECOUNT(long value) {
        this.updatecount = value;
    }

}

==> eam-wshub-proxyclient-12.1.0-21-sources.jar: net/datastream/schemas/mp_fields/EXTMENU_Type.java <==

package net.datastream.schemas.mp_fields;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlSeeAlso;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for EXTMENU_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="EXTMENU_Type">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}EXTMENUCODE"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}EXTMENUPARENT"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}EXTMENUTYPE"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}SEQUENCENUMBER"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}HIDEMENU" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}MOBILE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}MOBILEICON" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}DUX" minOccurs="0"/>
 *         <element name="UPDATECOUNT" type="{http://www.w3.org/2001/XMLSchema}long"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "EXTMENU_Type", propOrder = {
    "extmenucode",
    "extmenuparent",
    "extmenutype",
    "sequencenumber",
    "hidemenu",
    "mobile",
    "mobileicon",
    "dux",
    "updatecount"
})
@XmlSeeAlso({
    MENU_Type.class,
    FOLDER_Type.class,
    FUNCTION_Type.class
})
public class EXTMENU_Type {

    @XmlElement(name = "EXTMENUCODE", required = true)
    protected String extmenucode;
    @XmlElement(name = "EXTMENUPARENT", required = true)
    protected String extmenuparent;
    @XmlElement(name = "EXTMENUTYPE", required = true)
    protected String extmenutype;
    @XmlElement(name = "SEQUENCENUMBER")
    protected long sequencenumber;
    @XmlElement(name = "HIDEMENU")
    protected String hidemenu;
    @XmlElement(name = "MOBILE")
    protected String mobile;
    @XmlElement(name = "MOBILEICON")
    protected String mobileicon;
    @XmlElement(name = "DUX")
    protected String dux;
    @XmlElement(name = "UPDATECOUNT")
    protected long updatecount;

    /**
     * Gets the value of the extmenucode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEXTMENUCODE() {
        return extmenucode;
    }

    /**
     * Sets the value of the extmenucode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEXTMENUCODE(String value) {
        this.extmenucode = value;
    }

    /**
     * Gets the value of the extmenuparent property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEXTMENUPARENT() {
        return extmenuparent;
    }

    /**
     * Sets the value of the extmenuparent property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEXTMENUPARENT(String value) {
        this.extmenuparent = value;
    }

    /**
     * Gets the value of the extmenutype property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEXTMENUTYPE() {
        return extmenutype;
    }

    /**
     * Sets the value of the extmenutype property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEXTMENUTYPE(String value) {
        this.extmenutype = value;
    }

    /**
     * Gets the value of the sequencenumber property.
     * 
     */
    public long getSEQUENCENUMBER() {
        return sequencenumber;
    }

    /**
     * Sets the value of the sequencenumber property.
     * 
     */
    public void setSEQUENCENUMBER(long value) {
        this.sequencenumber = value;
    }

    /**
     * Gets the value of the hidemenu property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getHIDEMENU() {
        return hidemenu;
    }

    /**
     * Sets the value of the hidemenu property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setHIDEMENU(String value) {
        this.hidemenu = value;
    }

    /**
     * Gets the value of the mobile property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMOBILE() {
        return mobile;
    }

    /**
     * Sets the value of the mobile property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMOBILE(String value) {
        this.mobile = value;
    }

    /**
     * Gets the value of the mobileicon property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMOBILEICON() {
        return mobileicon;
    }

    /**
     * Sets the value of the mobileicon property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMOBILEICON(String value) {
        this.mobileicon = value;
    }

    /**
     * Gets the value of the dux property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDUX() {
        return dux;
    }

    /**
     * Sets the value of the dux property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDUX(String value) {
        this.dux = value;
    }

    /**
     * Gets the value of the updatecount property.
     * 
     */
    public long getUPDATECOUNT() {
        return updatecount;
    }

    /**
     * Sets the value of the updatecount property.
     * 
     */
    public void setUPDATECOUNT(long value) {
        this.updatecount = value;
    }

}
